@@ -5,7 +5,7 @@
 Box of handy tools for Sphinx.
 """
 #
-#  Copyright © 2020 Dominic Davis-Foster <dominic@davis-foster.co.uk>
+#  Copyright © 2020-2021 Dominic Davis-Foster <dominic@davis-foster.co.uk>
 #
 #  Permission is hereby granted, free of charge, to any person obtaining a copy
 #  of this software and associated documentation files (the "Software"), to deal
@@ -49,7 +49,7 @@ __author__: str = "Dominic Davis-Foster"
 __copyright__: str = "2020 Dominic Davis-Foster"
 
 __license__: str = "MIT License"
-__version__: str = "2.7.0"
+__version__: str = "2.8.1"
 __email__: str = "dominic@davis-foster.co.uk"
 
 __all__ = ["setup"]
@@ -59,7 +59,7 @@ def setup(app: Sphinx) -> "utils.SphinxExtMetadata":
 	"""
 	Setup :mod:`sphinx_toolbox`.
 
-	:param app: The Sphinx app.
+	:param app: The Sphinx application.
 	"""
 
 	# Ensure dependencies are set up
@@ -77,6 +77,7 @@ def setup(app: Sphinx) -> "utils.SphinxExtMetadata":
 	app.setup_extension("sphinx_toolbox.formatting")
 	app.setup_extension("sphinx_toolbox.installation")
 	app.setup_extension("sphinx_toolbox.issues")
+	app.setup_extension("sphinx_toolbox.latex")
 	app.setup_extension("sphinx_toolbox.rest_example")
 	app.setup_extension("sphinx_toolbox.shields")
 	app.setup_extension("sphinx_toolbox.source")
