@@ -12,7 +12,7 @@ Usage
 
 .. rst:role:: issue
 
-	Shows a link to the given issue on GitHub.
+	Role which shows a link to the given issue on GitHub.
 
 	If the issue exists, the link has a tooltip that shows the title of the issue.
 
@@ -31,7 +31,7 @@ Usage
 
 .. rst:role:: pull
 
-	Shows a link to the given pull request on GitHub.
+	Role which shows a link to the given pull request on GitHub.
 
 	If the pull requests exists, the link has a tooltip that shows the title of the pull requests.
 
@@ -155,7 +155,7 @@ class IssueNode(sphinx_toolbox.github.issues.IssueNode):
 	@deprecated(
 			deprecated_in="2.4.0",
 			removed_in="3.0.0",
-			current_version="2.7.0",
+			current_version="2.8.1",
 			details="Import from 'sphinx_toolbox.github.issues' instead.",
 			name="IssueNode",
 			)
@@ -166,7 +166,7 @@ class IssueNode(sphinx_toolbox.github.issues.IssueNode):
 visit_issue_node = deprecated(
 		deprecated_in="2.4.0",
 		removed_in="3.0.0",
-		current_version="2.7.0",
+		current_version="2.8.1",
 		details="Import from 'sphinx_toolbox.github.issues' instead.",
 		func=sphinx_toolbox.github.issues.visit_issue_node,
 		)
@@ -174,7 +174,7 @@ visit_issue_node = deprecated(
 depart_issue_node = deprecated(
 		deprecated_in="2.4.0",
 		removed_in="3.0.0",
-		current_version="2.7.0",
+		current_version="2.8.1",
 		details="Import from 'sphinx_toolbox.github.issues' instead.",
 		func=sphinx_toolbox.github.issues.depart_issue_node,
 		)
@@ -182,7 +182,7 @@ depart_issue_node = deprecated(
 get_issue_title = deprecated(
 		deprecated_in="2.4.0",
 		removed_in="3.0.0",
-		current_version="2.7.0",
+		current_version="2.8.1",
 		details="Import from 'sphinx_toolbox.github.issues' instead.",
 		func=sphinx_toolbox.github.issues.get_issue_title,
 		)
@@ -195,7 +195,7 @@ def setup(app: Sphinx) -> SphinxExtMetadata:
 
 	.. versionadded:: 1.0.0
 
-	:param app: The Sphinx app.
+	:param app: The Sphinx application.
 	"""
 
 	app.setup_extension("sphinx_toolbox.github")
